BFGraph: minHashKmer< HF > Struct Template Reference

BFGraph

Public Member Functions
minHashKmer< HF > Struct Template Reference

## Public Member Functions
| minHashKmer (const char *_s, int _k, int _g, HF _h, bool neighbor_hash)
| minHashKmer (const preAllocMinHashIterator< HF > &o)
bool | operator== (const minHashKmer &o)
bool | operator!= (const minHashKmer &o)
uint64_t | getHash () const
int | getPosition () const
int | getNbMin () const

The documentation for this struct was generated from the following file:

- src/minHashIterator.hpp